---
title: 헥토파이낸셜 상세 계약절차
category: 결제서비스 (채널설정 및 이용안내) > 이용안내 > 결제대행사 계약
seo:
  title: 헥토파이낸셜 상세 계약절차
  description: >-
    헥토파이낸셜의 전자결제 계약절차는 가입신청서 제출 - 계약안내 - 계약진행 - 계약완료 - 포트원 관리자콘솔 채널설정 - 개발진행 -
    카드사 심사로 이뤄집니다. 계약 절차를 순서별로 확인해보세요.
  keywords:
    - 헥토파이낸셜
    - 결제대행사 계약
tags:
  - 헥토파이낸셜
  - 결제대행사 계약
pgCompanies:
  - 헥토파이낸셜
searchTags:
  - 헥토계약방법
  - 헥토가입절차
  - 헥토가입
  - 헥토계약
  - 세틀뱅크 계약절차
  - 세틀뱅크 이용방법
  - 세틀뱅크계약
  - 헥토파이낸셜 가입방법
  - 헥토파이낸셜계약
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="" title="헥토파이낸셜과 계약을 맺으시기 위한 절차를 순서대로 자세히 알려드립니다." />

### **가입신청서 제출**

[포트원 관리자콘솔↗](https://admin.portone.io/) 안에서 헥토파이낸셜의 가입신청서를 제출합니다.

- 경로 : [포트원 관리자콘솔↗](https://admin.portone.io/) 회원가입 및 로그인 > 좌측 상단 \[전자결제 신청] 버튼 클릭 > 사업자등록증 업로드 > 원하는 결제수단 & 결제대행사 선택 후 제출

<Callout icon="" title="전자결제 신청방법 보러가기↗" />

![](/uploads/결제서비스/이용안내/결제대행사계약/홈_전자결제신청.png)

![](/uploads/결제서비스/이용안내/결제대행사계약/헥토파이낸셜.png)

### **헥토파이낸셜의 계약안내**

- 포트원으로 접수해주신 신청건은 당일 내 포트원 > 헥토파이낸셜측으로 전달되며 이후 2\~3영업일 내 헥토파이낸셜 계약부서로부터 자세한 안내를 받을 수 있습니다.
- 계약안내 메일은 가입신청서 제출 시 적어주신 담당자님 메일주소로 발송 됩니다.\
  (스팸함으로 종종 누락되기도 하니 스팸함까지 확인해주세요)

### **계약진행**

- 헥토파이낸셜의 안내 메일내용에 따라 필요한 구비서류 및 계약서 작성을 진행해주세요.
- 결제대행사에서 요구하는 기본적인 구비서류는 아래를 통해 참고해주시기 바라며 자세한 준비서류는 결제대행사로부터 안내받으실 메일에 기재되어 있습니다.

<Callout title="계약 구비서류 보러가기↗" icon="" />

### **계약완료**

- 계약서 작성 및 보증보험 가입등을 마치시면 계약이 완료됩니다. 다음 절차인 카드사 심사를 준비합니다.
- 혹시 상점정보가 미리 안내 되었다고 하더라도 카드사 심사 전에는 운영 환경 결제가 불가합니다. \
  (결제실패발생 될 수 있습니다.)

### **포트원 관리자콘솔 채널설정**

- 심사를 위해 포트원 관리자콘솔 에서 헥토파이낸셜의 테스트용 MID를 설정합니다.
- 연동하실 서비스(일반결제, 정기결제 등)에 맞게 알맞은 테스트용 상점아이디를 입력해주시기 바랍니다.

<Callout icon="" title="헥토파이낸셜 채널설정방법 보러가기 ↗" />

### **개발진행**

- 포트원의 개발 연동가이드를 참고하셔서 사이트 내 개발을 진행합니다.
- 심사를 받으실 사이트 내에서 결제서비스 연동을 완료해주셔야 하며, 모든 항목들이 최종 완성본 형태로 구현되어 있진 않아도 심사에 필요한 항목은 필수적으로 노출 · 동작되어야 합니다.
- 참고로 결제 이후 로직 까지는 심사하지 않고 결제창이 정상적으로 노출되는지, 결제창 안에 카드사가 잘 노출되는지 등을 검수합니다.

### **카드사 심사 진행**

- 모든 결제는 최종적으로 카드사 심사를 진행하셔야 실 결제서비스 사용이 가능합니다.
- 개발이 완료되면 헥토파이낸셜측으로 카드사 심사를 요청해주시면 되며, 헥토파이낸셜 측에서 각 카드사별로 심사를 요청하여 진행합니다. 카드사 심사는 각 카드사별로 진행되므로 완료일자가 정확하진 않으나 보통 2주정도 소요됩니다.
